@@ -1,4 +1,4 @@
 #!/usr/bin/python3
 import mdpeditor.runner
 
-mdpeditor.runner.run()
+sys.exit(mdpeditor.runner.run())
