@@ -1,5 +1,7 @@
 """run the command line interface if module is run"""
+import sys
+
 import mdpeditor.runner
 
 if __name__ == '__main__':
-    mdpeditor.runner.run()
+    sys.exit(mdpeditor.runner.run())
